sayid.query

The query DSL: a small zipper-based language for selecting nodes out of a recorded call tree - by function name, call id, tag, source position or ancestry - and returning the matches with their surrounding context.

The query DSL: a small zipper-based language for selecting nodes out of a
recorded call tree - by function name, call id, tag, source position or
ancestry - and returning the matches with their surrounding context.
raw docstring

eq*clj

(eq* pred v)
source

exec-querycljmultimethod

source

get-ids-from-file-line-rangeclj

(get-ids-from-file-line-range tree file start-line line)
source

get-ids-from-file-posclj

(get-ids-from-file-pos tree file line)
source

get-someclj

(get-some coll v)
source

get-some*clj

(get-some* f v)
source

init-bestclj

source

mk-query-fnclj

(mk-query-fn query-coll)
source

qclj

(q tree & body)
source

queryclj

(query tree pred-fn)
(query tree pred-map pred-final-fn)
source

some-mk-query-fnclj

(some-mk-query-fn queries)
source

traverse-tree-dissoc-zipperclj

(traverse-tree-dissoc-zipper tree)
source

cljdoc builds & hosts documentation for Clojure/Script libraries