sayid.util.other

General-purpose helpers that don't have a more specific home. Symbol and namespace helpers live in util.sym, source-reading in util.source.

General-purpose helpers that don't have a more specific home.  Symbol and
namespace helpers live in `util.sym`, source-reading in `util.source`.
raw docstring

$-cljmacro

($- m & body)
source

->intclj

(->int v)
source

->symbolclj

(->symbol v)
source

->vecclj

(->vec v)
source

apply-to-map-valsclj

(apply-to-map-vals f m)
source

arg-matchclj

(arg-match arglists args)
source

arg-match-safeclj

(arg-match-safe arglists args)
source

arg-matcher-fnclj

(arg-matcher-fn arglists)
source

arg-matcher-fn-memoclj

source

assoc-var-meta-to-fncljmacro

(assoc-var-meta-to-fn fn-sym meta-key)
source

atom?clj

(atom? v)
source

atom?->clj

(atom?-> maybe-atom)
source

back-intoclj

(back-into orig noob)

Puts the contents of noob into a collection of the same type as orig.

Puts the contents of `noob` into a collection of the same type as `orig`.
sourceraw docstring

cleanse-arglistclj

(cleanse-arglist arglist)

Clear out pre-condtions and tags.

Clear out pre-condtions and tags.
sourceraw docstring

clear-metaclj

(clear-meta v)
source

deep-zipmapclj

(deep-zipmap a b)
source

defaliascljmacro

(defalias alias source)
source

defalias-macrocljmacro

(defalias-macro alias source)
source

defalias-macro*clj

(defalias-macro* alias source)
source

derefable?clj

(derefable? v)
source

derefable?->clj

(derefable?-> maybe-ideref)
source

flatten-map-kv-pairsclj

(flatten-map-kv-pairs m)
source

fn*?clj

(fn*? maybe)
source

get-envcljmacro

(get-env)
source

get-someclj

(get-some coll v)
source

get-some*clj

(get-some* f v)
source

just-get-whatever-you-canclj

(just-get-whatever-you-can ns-sym clue)
source

obj-pred-action-elseclj

(obj-pred-action-else obj pred & {:keys [t t-fn f f-fn]})
source

quote-if-symclj

(quote-if-sym v)
source

replace$clj

(replace$ form)
source

src-in-metacljmacro

(src-in-meta & body)
source

cljdoc builds & hosts documentation for Clojure/Script libraries