sayid.util.source

Helpers for locating and reading the source of a function, used by inner tracing to recover the form it needs to instrument.

Helpers for locating and reading the source of a function, used by inner
tracing to recover the form it needs to instrument.
raw docstring

get-src-file-pathclj

(get-src-file-path s)
source

hunt-down-sourceclj

(hunt-down-source fn-sym)
source

mk-dummy-whitespaceclj

(mk-dummy-whitespace lines cols)
source

mk-positionalble-src-logging-push-back-rdrclj

(mk-positionalble-src-logging-push-back-rdr s file line col)
source

cljdoc builds & hosts documentation for Clojure/Script libraries