The in-memory capture store: the active workspace that traces record into, and the operations over it - reset, clear the log, enable/disable/remove traces, and look up what's traced.
The in-memory capture store: the active workspace that traces record into, and the operations over it - reset, clear the log, enable/disable/remove traces, and look up what's traced.
(remove-trace-*! ws type sym)Untrace all fns in the given name space.
Untrace all fns in the given name space.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |